==> jec-jask-cli-0.2.9.tgz: package/lib/index.js <==
"use strict";

var _jecJask = require("jec-jask");

var _jecJask2 = _interopRequireDefault(_jecJask);

var _ramda = require("ramda");

var R = _interopRequireWildcard(_ramda);

var _parseCli2 = require("./parseCli");

var _parseCli3 = _interopRequireDefault(_parseCli2);

var _generateAddActions = require("./generateAddActions");

var _generateAddActions2 = _interopRequireDefault(_generateAddActions);

var _generateModifyActions = require("./generateModifyActions");

var _generateModifyActions2 = _interopRequireDefault(_generateModifyActions);

var _generateWorkflowEventActions = require("./generateWorkflowEventActions");

var _generateWorkflowEventActions2 = _interopRequireDefault(_generateWorkflowEventActions);

var _filterByCLICommands = require("./filterByCLICommands");

var _filterByCLICommands2 = _interopRequireDefault(_filterByCLICommands);

var _render = require("./render");

var _render2 = _interopRequireDefault(_render);

var _distributeHooks = require("./distributeHooks");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

process.on("unhandledRejection", function (r) {
	return console.log(r);
});

var store = (0, _jecJask2.default)({
	listAllActions: _distributeHooks.listAllActions,
	writeAction: _distributeHooks.writeAction,
	readAction: _distributeHooks.readAction,
	persistStorage: _distributeHooks.persistStorage
});

var hasRunCliCommand = false;
store.subscribe(function () {
	if (!hasRunCliCommand) {
		var _store$getState = store.getState(),
		    __distributeStatus = _store$getState.__distributeStatus;

		if (__distributeStatus === "READY") {
			hasRunCliCommand = true;

			var _parseCli = (0, _parseCli3.default)(process.argv),
			    filter = _parseCli.filter,
			    command = _parseCli.command,
			    modifications = _parseCli.modifications;

			var noop = function noop() {
				return {
					actions: [],
					filterForRender: (0, _filterByCLICommands2.default)(filter)
				};
			};

			var actionGenerator = {
				add: _generateAddActions2.default,
				modify: _generateModifyActions2.default,
				start: (0, _generateWorkflowEventActions2.default)("start"),
				stop: (0, _generateWorkflowEventActions2.default)("stop"),
				done: (0, _generateWorkflowEventActions2.default)("done")
			}[command] || noop;

			var _actionGenerator = actionGenerator({
				filter: filter,
				modifications: modifications,
				state: store.getState()
			}),
			    actions = _actionGenerator.actions,
			    filterForRender = _actionGenerator.filterForRender;

			actions.forEach(store.dispatch);

			console.log((0, _render2.default)({
				filterTask: R.identity,
				giveColor: function giveColor() {
					return [];
				},
				headers: ["id", "score", "description", "priority", "tags", "project", "due", "start", "done", "recur"]
			}, (0, _jecJask.collateAllObjects)(store.getState()).filter(filterForRender)));
		}
	}
});

==> jec-jask-cli-0.3.1.tgz: package/lib/index.js <==
"use strict";

var _identity2 = require("ramda/src/identity");

var _identity3 = _interopRequireDefault(_identity2);

var _extends2 = require("babel-runtime/helpers/extends");

var _extends3 = _interopRequireDefault(_extends2);

var _jecJask = require("jec-jask");

var _jecJask2 = _interopRequireDefault(_jecJask);

var _parseCli2 = require("./parseCli");

var _parseCli3 = _interopRequireDefault(_parseCli2);

var _generateAddActions = require("./generateAddActions");

var _generateAddActions2 = _interopRequireDefault(_generateAddActions);

var _generateModifyActions = require("./generateModifyActions");

var _generateModifyActions2 = _interopRequireDefault(_generateModifyActions);

var _generateWorkflowEventActions = require("./generateWorkflowEventActions");

var _generateWorkflowEventActions2 = _interopRequireDefault(_generateWorkflowEventActions);

var _filterByCLICommands = require("./filterByCLICommands");

var _filterByCLICommands2 = _interopRequireDefault(_filterByCLICommands);

var _render = require("./render");

var _render2 = _interopRequireDefault(_render);

var _distributeHooks = require("./distributeHooks");

var distributeHooks = _interopRequireWildcard(_distributeHooks);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

process.on("unhandledRejection", function (r) {
	return console.log(r);
});

var store = (0, _jecJask2.default)((0, _extends3.default)({}, distributeHooks));

var hasRunCliCommand = false;
store.subscribe(function () {
	if (!hasRunCliCommand) {
		var _store$getState = store.getState(),
		    distrubuteStatus = _store$getState.distrubuteStatus;

		if (distrubuteStatus === "UP_TO_DATE") {
			hasRunCliCommand = true;

			var _parseCli = (0, _parseCli3.default)(process.argv),
			    filter = _parseCli.filter,
			    command = _parseCli.command,
			    modifications = _parseCli.modifications;

			var noop = function noop() {
				return {
					actions: [],
					filterForRender: (0, _filterByCLICommands2.default)(filter)
				};
			};

			var actionGenerator = {
				add: _generateAddActions2.default,
				modify: _generateModifyActions2.default,
				start: (0, _generateWorkflowEventActions2.default)("start"),
				stop: (0, _generateWorkflowEventActions2.default)("stop"),
				done: (0, _generateWorkflowEventActions2.default)("done")
			}[command] || noop;

			var _actionGenerator = actionGenerator({
				filter: filter,
				modifications: modifications,
				state: store.getState()
			}),
			    actions = _actionGenerator.actions,
			    filterForRender = _actionGenerator.filterForRender;

			actions.forEach(store.dispatch);

			console.log((0, _render2.default)({
				filterTask: _identity3.default,
				giveColor: function giveColor() {
					return [];
				},
				headers: ["id", "score", "description", "due", "project", "start", "priority", "tags", "recur"]
			}, (0, _jecJask.collateAllObjects)(store.getState()).filter(filterForRender)));
		}
	}
});
